package com.ruoyi.project.training.mapper;

import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.common.domain.DataEntity;
import com.ruoyi.project.training.domain.TByxWorkcertificate;

import java.util.List;
import java.util.Map;

/**
 * 作业证书一览Mapper接口
 *
 * @author ruoyi
 * @date 2020-12-01
 */
public interface TByxWorkcertificateMapper
{
    /**
     * 查询作业证书一览
     *
     * @param id 作业证书一览ID
     * @return 作业证书一览
     */
    public TByxWorkcertificate selectTByxWorkcertificateById(Long id);

    public TByxWorkcertificate selectTByxWorkcertificateByEmployeeid(String employeeid);

    /**
     * 查询作业证书一览列表
     *
     * @param TByxWorkcertificate 作业证书一览
     * @return 作业证书一览集合
     */
    @DataScope(deptAlias = "d")
    public List<TByxWorkcertificate> selectTByxWorkcertificateList(TByxWorkcertificate TByxWorkcertificate);

    /**
     * 定时任务查询作业证书一览列表
     *
     * @param TByxWorkcertificate 作业证书一览
     * @return 作业证书一览集合
     */
    public List<TByxWorkcertificate> selectList(TByxWorkcertificate TByxWorkcertificate);

    /**
     * 新增作业证书一览
     *
     * @param TByxWorkcertificate 作业证书一览
     * @return 结果
     */
    public int insertTByxWorkcertificate(TByxWorkcertificate TByxWorkcertificate);

    /**
     * 修改作业证书一览
     *
     * @param TByxWorkcertificate 作业证书一览
     * @return 结果
     */
    public int updateTByxWorkcertificate(TByxWorkcertificate TByxWorkcertificate);

    /**
     * 根据员工编号修改作业证书一览
     *
     * @param TByxWorkcertificate 作业证书一览
     * @return 结果
     */
    public int updateTByxWorkcertificateByEmployeeid(TByxWorkcertificate TByxWorkcertificate);

    /**
     * 删除作业证书一览
     *
     * @param id 作业证书一览ID
     * @return 结果
     */
    public int deleteTByxWorkcertificateById(Long id);

    /**
     * 批量删除作业证书一览
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTByxWorkcertificateByIds(Long[] ids);

    DataEntity selectCerData(Map param);
}
